pub fn compute_next_beta_value_from_current<F: Field>(
current_beta_value: &F,
inverses: &[F],
one_minus_elem_inverted: &[F],
claim_point: &[F],
flipped_bit_idx_and_values: &[(u32, bool)],
) -> FExpand description
Compute the next beta value from the previous by multiplying by appropriate inverses and challenge points given the flipped bits and their previous values. This is for when we have a single claim to compute the beta over.