pub fn compute_next_beta_values_vec_from_current<F: Field>(
current_beta_values: &[F],
inverses_vec: &[Vec<F>],
one_minus_elem_inverted_vec: &[Vec<F>],
claim_points: &[&[F]],
flipped_bit_idx_and_values: &[(u32, bool)],
) -> Vec<F>Expand description
Compute the next beta values from the previous by multiplying by appropriate inverses and challenge points given the flipped bits and their previous values. This is for when we have multiple claims to compute the beta over.