pub fn compute_flipped_bit_idx_and_values_lexicographic(
curr_val: u32,
next_val: u32,
) -> Vec<(u32, bool)>Expand description
Compute the flipped bits between a previous value and a current value, and return each of the flipped bits’ indices and previous value.