pub fn evaluate_mle_at_a_point_gray_codes<F: Field>(
mle: &MultilinearExtension<F>,
point: &[F],
) -> FExpand description
This function non-destructively evaluates an MLE at a given point using the gray codes iterator. Optimized version that uses 2 multiplications instead of 1.
Currently does not support for when the value in the point is either 0 or 1.